contexttools.Context
====================

.. inheritance-diagram:: abjad.tools.contexttools.Context.Context.Context
   :private-bases:

.. autoclass:: abjad.tools.contexttools.Context.Context.Context

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.contents_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.duration_in_seconds

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.engraver_consists

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.engraver_removals

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_semantic

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.leaves

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.music

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.preprolated_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.context_name

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_nonsemantic

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_parallel

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.name

Methods
-------

.. automethod:: abjad.tools.contexttools.Context.Context.Context.append

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.extend

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.index

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.insert

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.pop

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.remove

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__add__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__contains__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__delitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__getitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__iadd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__imul__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__len__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__radd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__repr__

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__setitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__str__

   .. note:: Inherited from `__builtin__.object`
